@@ -10,6 +10,7 @@ import hashlib
 import ifpd as fp
 from ifpd.sections import routes
 from ifpd.sections.probe_design.query import Query
+import logging
 import os
 import pandas as pd  # type: ignore
 import shlex
@@ -29,11 +30,10 @@ def zipFile(path, ziph, root=None):
     assert os.path.isfile(path), "file expected."
     oldRoot = ""
     new_path = path
-    if not type(None) == type(root):
+    if type(None) != type(root):
         oldRoot = os.path.commonpath([root, path])
-        if 0 != len(oldRoot):
-            if new_path.startswith(oldRoot):
-                new_path = new_path[len(oldRoot) :]
+        if len(oldRoot) != 0 and new_path.startswith(oldRoot):
+            new_path = new_path[len(oldRoot) :]
     ziph.write(path, new_path)
 
 
@@ -441,10 +441,10 @@ class Routes(routes.Routes):
         d["query"] = Query(query_id, self.qpath).data
         d["queryRoot"] = self.qpath
 
-        if "done" == d["query"]["status"]:
-            if "single" == d["query"]["type"]:
+        if d["query"]["status"] == "done":
+            if d["query"]["type"] == "single":
                 fpath = os.path.join(self.qpath, query_id, "candidates.tsv")
-            elif "spotting" == d["query"]["type"]:
+            elif d["query"]["type"] == "spotting":
                 fpath = os.path.join(self.qpath, query_id, "set_candidates.tsv")
             if not os.path.isfile(fpath):
                 d["query"]["status"] = "error"
@@ -586,9 +586,13 @@ class Routes(routes.Routes):
         """
 
         formData = bot.request.forms
-        queriedRegion = ""
+        queriedRegion = []
         if formData.start != formData.end:
-            queriedRegion = f"--region {formData.start} {formData.end}"
+            queriedRegion = [
+                "--region",
+                shlex.quote(formData.start),
+                shlex.quote(formData.end),
+            ]
         query_id = "%s:%s:%s:%s" % (
             formData.chromosome,
             formData.start,
@@ -623,8 +627,9 @@ class Routes(routes.Routes):
             "--min-d",
             shlex.quote(f"{min_dist}"),
         ]
-        if 0 != len(queriedRegion):
-            cmd.extend([shlex.quote(queriedRegion)])
+        if len(queriedRegion) != 0:
+            cmd.extend(queriedRegion)
+        logging.info(" ".join(cmd))
 
         config = configparser.ConfigParser()
         timestamp = time.time()
@@ -667,9 +672,13 @@ class Routes(routes.Routes):
         """
 
         formData = bot.request.forms
-        queriedRegion = ""
-        if formData.multi_start != formData.multi_end:
-            queriedRegion = f"--region {formData.multi_start} {formData.multi_end}"
+        queriedRegion = []
+        if formData.start != formData.end:
+            queriedRegion = [
+                "--region",
+                shlex.quote(formData.start),
+                shlex.quote(formData.end),
+            ]
         query_id = "%s:%s:%s:%s" % (
             formData.multi_chromosome,
             formData.multi_start,
@@ -705,8 +714,9 @@ class Routes(routes.Routes):
             "--window-shift",
             shlex.quote(f"{formData.multi_win_shift}"),
         ]
-        if 0 != len(queriedRegion):
-            cmd.extend([shlex.quote(queriedRegion)])
+        if len(queriedRegion) != 0:
+            cmd.extend(queriedRegion)
+        logging.info(" ".join(cmd))
 
         config = configparser.ConfigParser()
         timestamp = time.time()
@@ -765,7 +775,7 @@ class Routes(routes.Routes):
         dbPath = os.path.join(self.static_path, "db", dbDir)
         chrList = [x for x in os.listdir(dbPath) if not os.path.isdir(x)]
         chrList = [x for x in chrList if x not in [".log", ".config"]]
-        if 0 == len(chrList):
+        if not chrList:
             return '{"chrList":[]}'
         chrList.sort()
         return '{"chrList":["%s"]}' % '","'.join(chrList[::-1])
@@ -773,13 +783,13 @@ class Routes(routes.Routes):
     def queueStatus(routes, self):
         taskList = []
         for task in self.queue.queue:
-            if "ifpd_query_set" == task[0]:
+            if task[0] == "ifpd_query_set":
                 outdir_id = 4
-            elif "ifpd_query_probe" == task[0]:
+            elif task[0] == "ifpd_query_probe":
                 outdir_id = 3
             query_id = os.path.basename(task[outdir_id])
             data = Query(query_id, self.qpath).data
             taskList.append(os.path.basename(task[1]) + f' @{data["isotime"]}')
-        if 0 == len(taskList):
+        if not taskList:
             return '{"queue":[]}'
         return '{"queue": ["%s"]}' % '", "'.join(taskList)
